@@ -110,15 +110,6 @@ class Script:
 
         self.findCommandRun = False
 
-        # Assists with dealing with CORBA COMM_FAILURES.  A failure doesn't
-        # always mean an object disappeared - there just might be a network
-        # glitch.  So, on COMM_FAILURES, we might retry a few times before
-        # giving up on an object.  This might need to be overridden by the
-        # script.  See bug #397787.
-        #
-        self.commFailureWaitTime = settings.commFailureWaitTime
-        self.commFailureAttemptLimit = settings.commFailureAttemptLimit
-
         debug.println(debug.LEVEL_FINE, "NEW SCRIPT: %s" % self.name)
 
     def getListeners(self):
